"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HashPlanInspector = void 0;
const native_1 = require("../native");
const nx_json_1 = require("../config/nx-json");
const transform_objects_1 = require("../native/transform-objects");
const workspace_root_1 = require("../utils/workspace-root");
const find_project_for_path_1 = require("../project-graph/utils/find-project-for-path");
const create_task_graph_1 = require("../tasks-runner/create-task-graph");
const workspace_context_1 = require("../utils/workspace-context");
class HashPlanInspector {
    constructor(nxJson = (0, nx_json_1.readNxJson)(), projectGraph) {
        this.nxJson = nxJson;
        this.projectGraph = projectGraph;
        this.projectGraphRef = (0, native_1.transferProjectGraph)((0, transform_objects_1.transformProjectGraphForRust)(this.projectGraph));
        this.planner = new native_1.HashPlanner(this.nxJson, this.projectGraphRef);
    }
    async init() {
        const projectRootMap = (0, find_project_for_path_1.createProjectRootMappings)(this.projectGraph.nodes);
        const map = Object.fromEntries(projectRootMap.entries());
        const { externalReferences } = await (0, workspace_context_1.getNxWorkspaceFilesFromContext)(workspace_root_1.workspaceRoot, map, false);
        this.inspector = new native_1.HashPlanInspector(externalReferences.allWorkspaceFiles, this.projectGraphRef, externalReferences.projectFiles);
    }
    inspectHashPlan({ project, target, configuration }) {
        const taskGraph = (0, create_task_graph_1.createTaskGraph)(this.projectGraph, {}, [project], [target], undefined, {});
        const plansReference = this.planner.getPlansReference([
            `${project}:${target.indexOf(':') > -1 ? `"${target}"` : target}${configuration !== undefined ? ':' + configuration : ''}`,
        ], taskGraph);
        return this.inspector.inspect(plansReference);
    }
}
exports.HashPlanInspector = HashPlanInspector;
